@@ -75,19 +75,23 @@ validateStyle <- function(style, tableFormatType) {
     if (is.list(style) | is.null(style)) {
       omopgenerics::assertList(style, null = TRUE, named = TRUE)
       if (is.list(style)) {
-        notIn <- !names(style) %in% names(datatableStyleInternal("default"))
+        notIn <- switch (tableFormatType,
+          "datatable" = !names(style) %in% names(datatableStyleInternal("default")),
+          "reactable" = !names(style) %in% names(reactableStyleInternal("default")),
+          "gt" = !names(style) %in% names(gtStyleInternal("default")),
+          "flextable" = !names(style) %in% names(flextableStyleInternal("default"))
+        )
         if (sum(notIn) > 0 & tableFormatType == "datatable") {
           cli::cli_abort(c("`style` can only be defined for the following table parts in `datatable`: {datatableStyleInternal('default') |> names()}.",
                            "x" =  "{.strong {names(style)[notIn]}} {?is/are} not one of them."))
         }
-        notIn <- !names(style) %in% names(reactableStyleInternal("default"))
         if (sum(notIn) > 0 & tableFormatType == "reactable") {
           cli::cli_abort(c("`style` can only be defined for the following table parts in `reactable`: {datatableStyleInternal('default') |> names()}.",
                            "x" =  "{.strong {names(style)[notIn]}} {?is/are} not one of them."))
         }
-        notIn <- !names(style) %in% names(gtStyleInternal("default"))
         if (sum(notIn) > 0 & !tableFormatType %in% c("datatable", "reactable")) {
-          cli::cli_abort(c("`style` can only be defined for the following table parts in `gt` and `flextable`: {gtStyleInternal('default') |> names()}.",
+          names <- c("header", "header_name", "header_level", "column_name", "group_label", "title", "subtitle", "body")
+          cli::cli_abort(c("`style` can only be defined for the following table parts in `gt` and `flextable`: {names}.",
                            "x" =  "{.strong {names(style)[notIn]}} {?is/are} not one of them."))
         }
       }
