@@ -152,3 +152,25 @@ test_that("validate header works", {
   expect_warning(newX <- visTable(x, header = "c", hide = "b", type = "tibble"))
   expect_true("B" %in% colnames(newX))
 })
+
+test_that("global options works", {
+  result <- mockSummarisedResult()
+  setGlobalTableOptions("darwin", "tinytable")
+  tab <- visTable(result, header = "strata_level")
+  expect_true(class(tab)[1] == "tinytable")
+  expect_equal(
+    getTinytableStyle(tab, -1, 12),
+    dplyr::tibble(
+      "i" = -1, "j" = 12, "tabularray" = factor(""), "color" = "white", "background" = "#003399",
+      "fontsize" = NA, "alignv" = NA, "line" = "lbtr", "line_color" = "#003399",
+      "line_width" = 0.1, "bold" = TRUE, "italic" = FALSE, "monospace" = FALSE,
+      "strikeout" = FALSE, "underline" = FALSE, "indent" = NA, "colspan" = NA,
+      "rowspan" = NA_integer_, "bootstrap_css" = NA, "align" = NA
+    ),
+    ignore_attr = TRUE
+  )
+  tab <- visTable(result, type = "gt")
+  expect_true(class(tab)[1] == "gt_tbl")
+  options(visOmopResults.tableStyle = NULL)
+  options(visOmopResults.tableType = NULL)
+})
